@@ -1,6 +1,6 @@
 #! /bin/bash
 
-# $Id: build.sh,v 1.10 2003/01/07 22:08:16 jt Exp $
+# $Id: build.sh,v 1.11 2003/10/21 20:08:09 jt Exp $
 
 # vim: tabstop=4
 
@@ -15,16 +15,16 @@ pkg=fetchmail
 Prefix=/usr
 TmpDir=/tmp/$pkg.$$
 InstallPrefix=$TmpDir$Prefix
-BinDir=$InstallPrefix/bin
-LibDir=$InstallPrefix/lib
-ManDir=$InstallPrefix/man
-DocDir=$InstallPrefix/doc/$pkg-$version
-CygDocDir=$TmpDir/usr/doc/Cygwin
+
+DataDir=$InstallPrefix/share
+ManDir=$DataDir/man
+DocDir=$DataDir/doc/$pkg-$version
+CygDocDir=$DataDir/doc/Cygwin
 PatchDir=CYGWIN-PATCHES
-SrcDocDir=doc
 
 # configure
-configure --prefix=/usr --enable-NTLM --with-ssl --enable-fallback=procmail
+configure --prefix=/usr --datadir=/usr/share --mandir=/usr/share/man \
+	--enable-NTLM --with-ssl --enable-fallback=procmail
 
 # make
 make
